################################################################################
#                                                                              #
#      Splitting data into training set and validation set                     #
#                                                                              #
#      Author: S. Janitza <janitza@ibe.med.uni-muenchen.de>                    #
#                                                                              #
################################################################################


# Set working directory where data is stored

setwd("reproducible_files/Data/")


# Load data

data <- read.csv("data.csv", header = TRUE, sep = ",", as.is = TRUE)


##############################################
# Separation in training- and validation set #
##############################################

# Split data in training and validation set in ratio 2 : 1 (stratified sampling)

set.seed(123)       # seed for reproducibility (R version 2.13.1)

ID_pos <- sample(which(data$Stamm == "pos"), size = floor(length(which(data$Stamm == "pos"))/3))
ID_neg <- sample(which(data$Stamm == "neg"), size = floor(length(which(data$Stamm == "neg"))/3))


# Training data

training_data <- data[-c(ID_pos, ID_neg),]
write.csv(training_data, file = "training_data.csv", row.names = FALSE)


# Validation data

validation_data <- data[c(ID_pos, ID_neg),]
write.csv(validation_data, file = "validation_data.csv", row.names = FALSE)

