################################################################################
#                                                                              #
#      Validation of RF prediction rule                                        #
#                                                                              #
#      Author: S. Janitza <janitza@ibe.med.uni-muenchen.de>                    #
#                                                                              #
################################################################################


# Load packages

require("CMA")
require("randomForest")
require("ROCR")


# Load R object (RF prediction rule based on 10 best predictors)

load("R_Objects/RF_prediction_rule.Rda")


# Load validation data

validation_data <- read.csv("Data/validation_data.csv", header = TRUE, sep = ",", as.is = TRUE)



# Get predictions for validation data

y_hat_validation      <- predict(res_RF_pred_model, 
                                 newdata = validation_data[, colnames(validation_data) %in% rownames(importance(res_RF_pred_model))])

y_hat_validation_prob <- predict(res_RF_pred_model, 
                                 newdata = validation_data[, colnames(validation_data) %in% rownames(importance(res_RF_pred_model))], 
                                 type = "prob")


# Show important measures on validation data

(valid_error <- mean(y_hat_validation != validation_data$Stamm))
# -> error rate of 16.67%, i.e. 7 out of 42 observations were falsely classified

(valid_sens <- sum(y_hat_validation == "pos" & validation_data$Stamm == "pos")/sum(validation_data$Stamm == "pos"))
# -> sensitivity of 93.33%

(valid_spez <- sum(y_hat_validation == "neg" & validation_data$Stamm == "neg")/sum(validation_data$Stamm == "neg"))
# -> specificity of 58.33%

(valid_AUC <- performance(prediction(y_hat_validation_prob[,2], validation_data$Stamm),"auc")@y.values[[1]])
# -> area under the curve of 0.8917



# More information about validation data and about misclassified observations

table(y_hat_validation, validation_data$Stamm) # Cross tabulation with rightly and falsely classified observations

table(validation_data$Probe)                   # Get family information of observations in validation data  

validation_data$Probe[y_hat_validation != validation_data$Stamm] # Get family information of misclassified observations



# Plot AUC of RF prediction rule on validation data

graphics.off()
pdf(file = "ROC.pdf", height = 4, width = 4.2)

par(mar = c(6, 6, 0.5, 0.5))

plot(performance(prediction(y_hat_validation_prob[,2], validation_data$Stamm), "tpr", "fpr"), 
     xlab = "",
     ylab = "Sensitivity\n (Fraction of Gram-positives correctly\n identified as Gram-positive)", 
     main = "", 
     lwd = 2,
     col  = "black")
mtext(side = 1, text = "1 - Specificity\n (Fraction of Gram-negatives incorrectly\n identified as Gram-positive)", line = 5)

graphics.off()

